// Inclusion des fonctionnalits
#include "main.h"

// Variables
// La fentre du jeu
RenderWindow window;
// Pour la gestion des inputs
Input input;
// Pour stocker la fonte
Font font;
// Pour stocker le texte
Text txt;
// Exemple de valeur position axe X (gauche / droite)
int posX = 1;
// Astuce pour afficher un chiffre sous forme de string
char temp[256];

// Fonction main, point de dpart du programme
int main()
{
    // Options de la fentre
    ContextSettings options;
    options.antialiasingLevel = 8;
    // Cration d'une fentre type RenderWindow
    window.create(VideoMode(WIN_WIDTH, WIN_HEIGHT, 32), "Titre de la fentre", Style::Default, options);
    // Activation du vsync
    window.setVerticalSyncEnabled(true);

    // Chargement fonte
    LoadFont();
    
    // On rgle toutes les proprits de celui-ci
    SetText(txt, "Mon texte !");

    // Prparation des formes
    // Cercle
    CircleShape circleShape(75);
    circleShape.setFillColor(Color(100, 175, 80, 150));
    circleShape.setOutlineColor(Color::Red);
    circleShape.setOutlineThickness(5);
    circleShape.setPosition(posX, 80);
    // Rectangle
    RectangleShape rectangleShape(Vector2f(120.f, 50.f));
    rectangleShape.setPosition(200, 300);
    rectangleShape.setFillColor(Color(100, 115, 180, 200));
    rectangleShape.setSize(Vector2f(180.f, 100.f));
    // Triangle (cercle avec 3 cts)
    CircleShape triangle(80.f, 3);
    triangle.setFillColor(Color::Green);
    // Forme libre
    // cre une forme vide
    ConvexShape convex;
    // dfinit le nombre de points (5)
    convex.setPointCount(5);
    // dfinit les points
    convex.setPoint(0, Vector2f(0.f, 0.f));
    convex.setPoint(1, Vector2f(150.f, 10.f));
    convex.setPoint(2, Vector2f(120.f, 90.f));
    convex.setPoint(3, Vector2f(30.f, 100.f));
    convex.setPoint(4, Vector2f(0.f, 50.f));

    convex.setPosition(500, 400);
    
    
    // Boucle qui tourne tant que la fentre est ouverte
    while (window.isOpen())
    {
        Event event; // Variable pour grer l'vnement
        // On boucle sur les vnements
        while (window.pollEvent(event))
        {
            // Gestion des inputs / events
            input.InputHandler(event, window);
            CheckBtn();
            circleShape.setPosition(posX, 80);
        }

        // Couleur de la fentre en noir
        window.clear(Color::Black);

        // C'est ici que l'on dessine les lments du jeu
        window.draw(txt);
        window.draw(circleShape);
        window.draw(rectangleShape);
        window.draw(triangle);
        window.draw(convex);

        // Dessiner  l'cran tous les lments
        window.display();
    }

    // Fin du programme
    return 0;
}

// Chargement de la police d'criture
void LoadFont()
{
    // On vrifie que la police est bien charge
    if (!font.loadFromFile("res/poppins.ttf"))
    {
        // Si erreur
        cout << "Erreur chargement fonte" << endl;
    }
}

void SetText(Text &txt, String str)
{
    // On lui indique quelle police utiliser
    txt.setFont(font);
    // On indique la chane de caractres  afficher
    txt.setString(str);
    // On indique la taille de la police d'criture
    txt.setCharacterSize(26);
    // On donne la couleur
    txt.setFillColor(Color::Cyan);
    // Modification du style
    txt.setStyle(Text::Bold | Text::Underlined);
}

void CheckBtn()
{
    if (input.GetButton().left == true)
    {
        SetText(txt, "Left");
        posX -= 10;
        // Exemple de limitation de valeur
        if (posX < 0)
            posX = 0;
        sprintf_s(temp, "%d", posX);
        SetText(txt, temp);
    }
    if (input.GetButton().right == true)
    {
        SetText(txt, "Right");
        posX += 10;
        // Exemple de limitation de valeur
        if (posX > WIN_WIDTH)
            posX = WIN_WIDTH;
        sprintf_s(temp, "%d", posX);
        SetText(txt, temp);
    }
    if (input.GetButton().up == true)
    {
        SetText(txt, "Up");
    }
    if (input.GetButton().down == true)
    {
        SetText(txt, "Down");
    }
    if (input.GetButton().escape == true)
    {
        window.close();
    }
    if (input.GetButton().attack == true)
    {
        SetText(txt, "Attack");
    }

}